package org.bkt.omfl.blocks;

import net.minecraft.block.Block;
import net.minecraft.block.BlockState;
import net.minecraft.block.CropBlock;
import net.minecraft.block.ShapeContext;
import net.minecraft.item.Item;
import net.minecraft.item.ItemConvertible;
import net.minecraft.state.StateManager;
import net.minecraft.state.property.IntProperty;
import net.minecraft.state.property.Properties;
import net.minecraft.state.property.Property;
import net.minecraft.util.math.BlockPos;
import net.minecraft.util.math.MathHelper;
import net.minecraft.util.shape.VoxelShape;
import net.minecraft.world.BlockView;
import net.minecraft.world.World;

public class OmflCropBlock extends CropBlock {

    public static final int OMFL_MAX_AGE = 3;
    public static final IntProperty OMFL_AGE = Properties.AGE_3;

    private static final VoxelShape[] AGE_TO_SHAPE = new VoxelShape[]{
            Block.createCuboidShape(0.0D, 0.0D, 0.0D, 16.0D, 2.0D, 16.0D),
            Block.createCuboidShape(0.0D, 0.0D, 0.0D, 16.0D, 8.0D, 16.0D),
            Block.createCuboidShape(0.0D, 0.0D, 0.0D, 16.0D, 12.0D, 16.0D),
            Block.createCuboidShape(0.0D, 0.0D, 0.0D, 16.0D, 16.0D, 16.0D)
    };

    public OmflCropBlock(Settings settings) {
        super(settings);
    }

    private Item seed;

    public void setSeedsItem(Item seed) {
        this.seed = seed;
    }

    @Override
    protected ItemConvertible getSeedsItem() {
        return (ItemConvertible) this.seed;
    }

    @Override
    protected VoxelShape getOutlineShape(BlockState state, BlockView world, BlockPos pos, ShapeContext context) {
        return AGE_TO_SHAPE[getAge(state)];
    }

    @Override
    protected IntProperty getAgeProperty() {
        return OMFL_AGE;
    }

    @Override
    public int getMaxAge() {
        return OMFL_MAX_AGE;
    }

    @Override
    protected int getGrowthAmount(World world) {
        // 改一下生长速率，长慢一点
        return MathHelper.nextInt(world.random, 1, 2);
    }

    @Override
    protected void appendProperties(StateManager.Builder<Block, BlockState> builder) {
        // 故意不加入原版的AGE然后加入我的AGE。不这样改的话CropBlock的构造函数会爆错
        //super.appendProperties(builder);
        builder.add(new Property[]{(Property) OMFL_AGE});
    }
}
